@@ -17,11 +17,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "peas-dirs.h"
 
@@ -51,54 +51,54 @@ BOOL WINAPI DllMain (HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
 #endif
 #endif
 
-gchar *
+char *
 peas_dirs_get_data_dir (void)
 {
-  gchar *data_dir;
+  char *data_dir;
 
 #ifdef G_OS_WIN32
-  gchar *win32_dir;
+  char *win32_dir;
 
   win32_dir = g_win32_get_package_installation_directory_of_module (libpeas_dll);
 
-  data_dir = g_build_filename (win32_dir, "share", "libpeas-1.0", NULL);
+  data_dir = g_build_filename (win32_dir, "share", "libpeas-2", NULL);
   g_free (win32_dir);
 #elif defined (OS_OSX)
   data_dir = peas_dirs_os_x_get_data_dir ();
 #else
-  data_dir = g_build_filename (DATADIR, "libpeas-1.0", NULL);
+  data_dir = g_build_filename (DATADIR, "libpeas-2", NULL);
 #endif
 
   return data_dir;
 }
 
-gchar *
+char *
 peas_dirs_get_lib_dir (void)
 {
-  gchar *lib_dir;
+  char *lib_dir;
 
 #ifdef G_OS_WIN32
-  gchar *win32_dir;
+  char *win32_dir;
 
   win32_dir = g_win32_get_package_installation_directory_of_module (libpeas_dll);
 
-  lib_dir = g_build_filename (win32_dir, "lib", "libpeas-1.0", NULL);
+  lib_dir = g_build_filename (win32_dir, "lib", "libpeas-2", NULL);
   g_free (win32_dir);
 #elif defined (OS_OSX)
   lib_dir = peas_dirs_os_x_get_lib_dir ();
 #else
-  lib_dir = g_build_filename (LIBDIR, "libpeas-1.0", NULL);
+  lib_dir = g_build_filename (LIBDIR, "libpeas-2", NULL);
 #endif
 
   return lib_dir;
 }
 
-gchar *
-peas_dirs_get_plugin_loader_dir (const gchar *loader_name)
+char *
+peas_dirs_get_plugin_loader_dir (const char *loader_name)
 {
-  const gchar *env_var;
-  gchar *lib_dir;
-  gchar *loader_dir;
+  const char *env_var;
+  char *lib_dir;
+  char *loader_dir;
 
   env_var = g_getenv ("PEAS_PLUGIN_LOADERS_DIR");
   if (env_var != NULL)
@@ -112,13 +112,13 @@ peas_dirs_get_plugin_loader_dir (const gchar *loader_name)
   return loader_dir;
 }
 
-gchar *
+char *
 peas_dirs_get_locale_dir (void)
 {
-  gchar *locale_dir;
+  char *locale_dir;
 
 #ifdef G_OS_WIN32
-  gchar *win32_dir;
+  char *win32_dir;
 
   win32_dir = g_win32_get_package_installation_directory_of_module (libpeas_dll);
 
@@ -133,4 +133,3 @@ peas_dirs_get_locale_dir (void)
 
   return locale_dir;
 }
-
