@@ -17,18 +17,28 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __PEAS_ENGINE_PRIV_H__
-#define __PEAS_ENGINE_PRIV_H__
+#pragma once
 
+#include <glib-object.h>
+
+#include "peas-engine.h"
+#include "peas-plugin-info.h"
 #include "peas-version-macros.h"
 
 G_BEGIN_DECLS
 
 PEAS_AVAILABLE_IN_ALL
-void _peas_engine_shutdown (void);
+void     _peas_engine_shutdown          (void);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+GObject *_peas_engine_create_extensionv (PeasEngine     *engine,
+                                         PeasPluginInfo *info,
+                                         GType           extension_type,
+                                         guint           n_parameters,
+                                         GParameter     *parameters);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 G_END_DECLS
-
-#endif /* __PEAS_ENGINE_PRIV_H__ */
