@@ -18,6 +18,8 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -32,7 +34,7 @@
  *
  * #PeasExtensionBase can optionally be used as a base class for the extensions
  * of your plugin. By inheriting from it, you will make your extension able to
- * access the related [struct@PluginInfo], and especially the location where all
+ * access the related [class@PluginInfo], and especially the location where all
  * the data of your plugin lives.
  *
  * Non-C extensions will usually not inherit from this class: Python
@@ -40,9 +42,10 @@
  * the same purpose.
  **/
 
-struct _PeasExtensionBasePrivate {
+typedef struct _PeasExtensionBasePrivate
+{
   PeasPluginInfo *info;
-};
+} PeasExtensionBasePrivate;
 
 /* properties */
 enum {
@@ -54,12 +57,18 @@ enum {
 
 static GParamSpec *properties[N_PROPERTIES] = { NULL };
 
-G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PeasExtensionBase,
-                                     peas_extension_base,
-                                     G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PeasExtensionBase, peas_extension_base, G_TYPE_OBJECT)
 
-#define GET_PRIV(o) \
-  (peas_extension_base_get_instance_private (o))
+static void
+peas_extension_base_finalize (GObject *object)
+{
+  PeasExtensionBase *extbase = PEAS_EXTENSION_BASE (object);
+  PeasExtensionBasePrivate *priv = peas_extension_base_get_instance_private (extbase);
+
+  g_clear_object (&priv->info);
+
+  G_OBJECT_CLASS (peas_extension_base_parent_class)->finalize (object);
+}
 
 static void
 peas_extension_base_get_property (GObject    *object,
@@ -72,11 +81,13 @@ peas_extension_base_get_property (GObject    *object,
   switch (prop_id)
     {
     case PROP_PLUGIN_INFO:
-      g_value_set_boxed (value, peas_extension_base_get_plugin_info (extbase));
+      g_value_set_object (value, peas_extension_base_get_plugin_info (extbase));
       break;
+
     case PROP_DATA_DIR:
       g_value_take_string (value, peas_extension_base_get_data_dir (extbase));
       break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -90,13 +101,14 @@ peas_extension_base_set_property (GObject      *object,
                                   GParamSpec   *pspec)
 {
   PeasExtensionBase *extbase = PEAS_EXTENSION_BASE (object);
-  PeasExtensionBasePrivate *priv = GET_PRIV (extbase);
+  PeasExtensionBasePrivate *priv = peas_extension_base_get_instance_private (extbase);
 
   switch (prop_id)
     {
     case PROP_PLUGIN_INFO:
-      priv->info = g_value_get_boxed (value);
+      priv->info = g_value_dup_object (value);
       break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -113,22 +125,23 @@ peas_extension_base_class_init (PeasExtensionBaseClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+  object_class->finalize = peas_extension_base_finalize;
   object_class->get_property = peas_extension_base_get_property;
   object_class->set_property = peas_extension_base_set_property;
 
   /**
    * PeasExtensionBase:plugin-info:
    *
-   * The [struct@PluginInfo] related to the current plugin.
+   * The [class@PluginInfo] related to the current plugin.
    */
   properties[PROP_PLUGIN_INFO] =
-    g_param_spec_boxed ("plugin-info",
-                        "Plugin Information",
-                        "Information related to the current plugin",
-                        PEAS_TYPE_PLUGIN_INFO,
-                        G_PARAM_READWRITE |
-                        G_PARAM_CONSTRUCT_ONLY |
-                        G_PARAM_STATIC_STRINGS);
+    g_param_spec_object ("plugin-info",
+                         "Plugin Information",
+                         "Information related to the current plugin",
+                         PEAS_TYPE_PLUGIN_INFO,
+                         G_PARAM_READWRITE |
+                         G_PARAM_CONSTRUCT_ONLY |
+                         G_PARAM_STATIC_STRINGS);
 
   /**
    * PeasExtensionBase:data-dir:
@@ -157,13 +170,13 @@ peas_extension_base_class_init (PeasExtensionBaseClass *klass)
  *
  * Get information relative to @extbase.
  *
- * Returns: (transfer none): the [struct@PluginInfo] relative
+ * Returns: (transfer none): the [class@PluginInfo] relative
  *   to the #PeasExtensionBase.
  */
 PeasPluginInfo *
 peas_extension_base_get_plugin_info (PeasExtensionBase *extbase)
 {
-  PeasExtensionBasePrivate *priv = GET_PRIV (extbase);
+  PeasExtensionBasePrivate *priv = peas_extension_base_get_instance_private (extbase);
 
   g_return_val_if_fail (PEAS_IS_EXTENSION_BASE (extbase), NULL);
 
@@ -180,10 +193,10 @@ peas_extension_base_get_plugin_info (PeasExtensionBase *extbase)
  * Returns: A newly allocated string with the path of the
  *   directory where the plugin should look for its data files
  */
-gchar *
+char *
 peas_extension_base_get_data_dir (PeasExtensionBase *extbase)
 {
-  PeasExtensionBasePrivate *priv = GET_PRIV (extbase);
+  PeasExtensionBasePrivate *priv = peas_extension_base_get_instance_private (extbase);
 
   g_return_val_if_fail (PEAS_IS_EXTENSION_BASE (extbase), NULL);
 
