@@ -17,17 +17,17 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <glib.h>
 #include <glib-object.h>
 #include <gmodule.h>
 
-#include <libpeas/peas.h>
+#include <libpeas.h>
 
 #include "introspection-abstract.h"
 #include "introspection-base.h"
@@ -38,9 +38,6 @@
 #include "extension-c-abstract.h"
 #include "extension-c-plugin.h"
 
-/* Used by the local linkage test */
-G_MODULE_EXPORT gpointer global_symbol_clash;
-
 static void introspection_base_iface_init (IntrospectionBaseInterface *iface);
 static void introspection_extension_c_iface_init (IntrospectionCallableInterface *iface);
 static void introspection_has_prerequisite_iface_init (IntrospectionHasPrerequisiteInterface *iface);
@@ -91,7 +88,7 @@ testing_extension_c_plugin_call_no_args (IntrospectionCallable *callable)
 {
 }
 
-static gchar *
+static char *
 testing_extension_c_plugin_call_with_return (IntrospectionCallable *callable)
 {
   return g_strdup ("Hello, World!");
@@ -106,9 +103,9 @@ testing_extension_c_plugin_call_single_arg (IntrospectionCallable *callable,
 
 static void
 testing_extension_c_plugin_call_multi_args (IntrospectionCallable *callable,
-                                            gint                   in,
-                                            gint                  *out,
-                                            gint                  *inout)
+                                            int                    in,
+                                            int                   *out,
+                                            int                   *inout)
 {
   *out = *inout;
   *inout = in;
