@@ -17,12 +17,13 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __TESTING_LOADABLE_PLUGIN_H__
-#define __TESTING_LOADABLE_PLUGIN_H__
+#pragma once
 
-#include <libpeas/peas.h>
+#include <libpeas.h>
 
 G_BEGIN_DECLS
 
@@ -54,5 +55,3 @@ GType                 testing_loadable_plugin_get_type (void) G_GNUC_CONST;
 G_MODULE_EXPORT void  peas_register_types              (PeasObjectModule *module);
 
 G_END_DECLS
-
-#endif /* __TESTING_LOADABLE_PLUGIN_H__ */
