@@ -17,10 +17,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __TESTING_UTIL_H__
-#define __TESTING_UTIL_H__
+#pragma once
 
 #include <libpeas/peas-engine.h>
 
@@ -47,7 +48,7 @@ int         testing_util_run_tests       (void);
 
 
 PEAS_TEST_EXPORT
-void        testing_util_push_log_hook   (const gchar *pattern);
+void        testing_util_push_log_hook   (const char *pattern);
 
 PEAS_TEST_EXPORT
 void        testing_util_pop_log_hook    (void);
@@ -59,5 +60,3 @@ void        testing_util_pop_log_hooks   (void);
 #define testing_util_engine_new() (testing_util_engine_new_full (FALSE))
 
 G_END_DECLS
-
-#endif /* __TESTING_UTIL_H__ */
